searchData={"items":[{"type":"behaviour","title":"ElixirExt.Registry","doc":"The ElixirExt.Registry module is used to define the behaviour that is necessary to be qualified as a `RegMod` for name registration of processes.\n\nThe definition according to the Elixir Docs (found [here](https://hexdocs.pm/elixir/GenServer.html#module-name-registration)) is as follows:\n> The :via option expects a module that exports register_name/2, unregister_name/1, whereis_name/1 and send/2.\n> One such example is the :global module which uses these functions for keeping the list of names of processes and their associated PIDs that are available globally for a network of Elixir nodes.\n> Elixir also ships with a local, decentralized and scalable registry called Registry for locally storing names that are generated dynamically.\n\nThe definition according to the Erlang Docs (found [here](https://www.erlang.org/doc/man/gen_server.html#type-server_name)) is similar:\n> Register the gen_server process with the registry represented by RegMod.\n> The RegMod callback is to export the functions register_name/2, unregister_name/1, whereis_name/1, and send/2, which are to behave like the corresponding functions in global.\n> Thus, {via,global,GlobalName} is a valid reference equivalent to {global,GlobalName}.\n\nThe following callbacks and typespecs are copied over from the global registry definitions in order to ensure that we have the typespecs as maintained by Erlang's global.","ref":"ElixirExt.Registry.html"},{"type":"callback","title":"ElixirExt.Registry.register_name/2","doc":"","ref":"ElixirExt.Registry.html#c:register_name/2"},{"type":"callback","title":"ElixirExt.Registry.send/2","doc":"","ref":"ElixirExt.Registry.html#c:send/2"},{"type":"callback","title":"ElixirExt.Registry.unregister_name/1","doc":"","ref":"ElixirExt.Registry.html#c:unregister_name/1"},{"type":"callback","title":"ElixirExt.Registry.whereis_name/1","doc":"","ref":"ElixirExt.Registry.html#c:whereis_name/1"},{"type":"module","title":"Reginald","doc":"Reginald is a simple distributed registry built on top of the built-in Erlang `:pg` module.\n\nThis module provides the public API of Reginald, while the internal modules provide the actual implementations.","ref":"Reginald.html"},{"type":"function","title":"Reginald.child_spec/1","doc":"","ref":"Reginald.html#child_spec/1"},{"type":"function","title":"Reginald.register_name/2","doc":"","ref":"Reginald.html#register_name/2"},{"type":"function","title":"Reginald.send/2","doc":"","ref":"Reginald.html#send/2"},{"type":"function","title":"Reginald.start_link/1","doc":"","ref":"Reginald.html#start_link/1"},{"type":"function","title":"Reginald.unregister_name/1","doc":"","ref":"Reginald.html#unregister_name/1"},{"type":"function","title":"Reginald.whereis_name/1","doc":"","ref":"Reginald.html#whereis_name/1"},{"type":"type","title":"Reginald.reg_mod/0","doc":"","ref":"Reginald.html#t:reg_mod/0"},{"type":"module","title":"Reginald.Backends.PG.Locks","doc":"Reginald.Backends.PG.Locks is a simplistic GenServer based locking mechanism.","ref":"Reginald.Backends.PG.Locks.html"},{"type":"function","title":"Reginald.Backends.PG.Locks.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Reginald.Backends.PG.Locks.html#child_spec/1"},{"type":"function","title":"Reginald.Backends.PG.Locks.lock/3","doc":"","ref":"Reginald.Backends.PG.Locks.html#lock/3"},{"type":"function","title":"Reginald.Backends.PG.Locks.lock_async/3","doc":"","ref":"Reginald.Backends.PG.Locks.html#lock_async/3"},{"type":"function","title":"Reginald.Backends.PG.Locks.start_link/1","doc":"","ref":"Reginald.Backends.PG.Locks.html#start_link/1"},{"type":"function","title":"Reginald.Backends.PG.Locks.unlock/3","doc":"","ref":"Reginald.Backends.PG.Locks.html#unlock/3"},{"type":"module","title":"Reginald.Backends.PG.Supervisor","doc":"`Reginald.Backends.PG.Supervisor` is the main entrypoint for raising all of the necessary child components for running Reginald.Backends.PG.\n\nYou should probably never reference it directly, and instead use the public API module `Reginald`.","ref":"Reginald.Backends.PG.Supervisor.html"},{"type":"function","title":"Reginald.Backends.PG.Supervisor.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Reginald.Backends.PG.Supervisor.html#child_spec/1"},{"type":"function","title":"Reginald.Backends.PG.Supervisor.start_link/1","doc":"Starts the `PG.Supervisor`.\n\nPassed options must include a `:name`.","ref":"Reginald.Backends.PG.Supervisor.html#start_link/1"},{"type":"module","title":"Reginald.Backends.Registry.Supervisor","doc":"`Reginald.Backends.Registry.Supervisor` is the main entrypoint for raising all of the necessary child components for running Reginald.Backends.Registry.\n\nYou should probably never reference it directly, and instead use the public API module `Reginald`.","ref":"Reginald.Backends.Registry.Supervisor.html"},{"type":"function","title":"Reginald.Backends.Registry.Supervisor.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Reginald.Backends.Registry.Supervisor.html#child_spec/1"},{"type":"function","title":"Reginald.Backends.Registry.Supervisor.start_link/1","doc":"Starts the `Backends.Registry.Supervisor`.\n\nPassed options must include a `:name` and a `:keys` value, which must be either `:unique` or `:duplicate`.\n\nIn addition to the `:name` and the `:keys` values, we also allow passing all of the native `Registry.start_link/1` options.","ref":"Reginald.Backends.Registry.Supervisor.html#start_link/1"},{"type":"extras","title":"Reginald","doc":"# Reginald\n\nReginald is a simple distributed registry built in pure Elixir on top of the built-in Erlang `:pg` module.","ref":"readme.html"},{"type":"extras","title":"Motivations - Reginald","doc":"I've recently started experimenting with distributed registries, after seeing various posts and examples of different Distributed Erlang/Elixir helpers, such as the built-in `:global` module, `syn`, and `horde`.\n\nAfter reading a lot, I started benchmarking them in a similar way to what @ostinelli did almost a decade ago. The benchmarks can be seen here: [probably-not/regbench](https://www.github.com/probably-not/regbench). The benchmarks showed some drastically different details than what most people assume:\n- `syn` is very (and likely the best choice to be honest), at the expense of being written in Erlang as opposed to Elixir (which makes it more difficult to understand and debug for people who aren't familiar with Erlang)\n- `:pg` used to be slow back when it was first benchmarked by @ostinelli, however now it is blazing fast, at the level of `syn`. However, it isn't exactly a registry (although as you'll see with Reginald, it can easily be modified to be one)\n- `:global` is slow, but not unreasonable so (unless you are working with a gigantic amount of registrations per second)\n- `:horde` is by far the slowest, although for some reason people always immediately say \"don't use global, use horde instead\", which seems... insane to me... it doesn't look like there were any benchmarks between horde and any other option, but people immediately say to use it instead of anything else.\n\nAfter doing these benchmarks, I decided that I wanted to build a Registry that would work with Distributed Elixir, and be written in pure Elixir, while being as fast as possible. The result is Reginald, your simple Distributed blazing-fast registry.","ref":"readme.html#motivations"},{"type":"extras","title":"Usage - Reginald","doc":"Reginald can be either started directly with `Reginald.start_link/1` or started as part of a supervisor by adding `{Reginald, name: MyApp.Reginald}` to your supervision tree.\n\nA `:name` option must be passed as the arguments to `Reginald.start_link/1`.\n\nFor usage as a Registry, simply use a via module like the following: `{:via, Reginald, {MyApp.Reginald, \"any id\"}}`, for example:\n\n```elixir\ndefmodule ExampleGenServer do\n  use GenServer\n\n  def start_link(id) do\n    GenServer.start_link(__MODULE__, id, name: via_tuple(id))\n  end\n\n  def via_tuple(id) do\n    {:via, Reginald, {MyApp.Reginald, id}}\n  end\n\n  def hello(id) do\n    GenServer.cast(via_tuple(id), :hello)\n  end\n\n  @impl true\n  def init(id) do\n    {:ok, id}\n  end\n\n  @impl true\n  def handle_cast(:hello, id) do\n    IO.puts(\"Got Hello!\")\n    {:noreply, id}\n  end\nend\n```","ref":"readme.html#usage"},{"type":"extras","title":"Installation - Reginald","doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `reginald` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:reginald, \">= 0.0.0\"}\n  ]\nend\n```\n\nDocumentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at  .","ref":"readme.html#installation"},{"type":"extras","title":"Changelog","doc":"# Changelog\nAll notable changes to this project will be documented in this file.\n\nThe format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),\nand this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).\n\n## [Unreleased]\n#","ref":"changelog.html"},{"type":"extras","title":"Added - Changelog","doc":"- Added new features\n\n#","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"- Changed an existing functionality\n\n#","ref":"changelog.html#changed"},{"type":"extras","title":"Deprecated - Changelog","doc":"- Deprecated a feature so that it can be removed in a later release\n\n#","ref":"changelog.html#deprecated"},{"type":"extras","title":"Removed - Changelog","doc":"- Removed a feature\n\n#","ref":"changelog.html#removed"},{"type":"extras","title":"Fixed - Changelog","doc":"- Fixed a bugfix\n\n#","ref":"changelog.html#fixed"},{"type":"extras","title":"Security - Changelog","doc":"- Patched a security vulnerability\n\n[Unreleased]: https://github.com/probably-not/reginald/compare/v0.1.0...HEAD\n[0.1.0]: https://github.com/probably-not/reginald/releases/tag/v0.1.0","ref":"changelog.html#security"}],"content_type":"text/markdown"}